@@ -1249,9 +1249,6 @@ _expectations = {
         """,
     'openbsd3':
         """
-        test_audioop
-        test_rgbimg
-        test_imageop
         test_aepack
         test_al
         test_applesingle
@@ -1318,6 +1315,7 @@ _expectations['freebsd5'] = _expectations['freebsd4']
 _expectations['freebsd6'] = _expectations['freebsd4']
 _expectations['freebsd7'] = _expectations['freebsd4']
 
+_expectations['openbsd5'] = _expectations['openbsd3']
 _expectations['openbsd4'] = _expectations['openbsd3']
 
 class _ExpectedSkips:
