@@ -166,107 +166,6 @@ class TestCopy(unittest.TestCase):
         x = C(42)
         self.assertEqual(copy.copy(x), x)
 
-    # tests for copying extension types, iff module trycopy is installed
-    def test_copy_classictype(self):
-        from _testcapi import make_copyable
-        x = make_copyable([23])
-        y = copy.copy(x)
-        self.assertEqual(x, y)
-        self.assertEqual(x.tag, y.tag)
-        self.assert_(x is not y)
-        self.assert_(x.tag is y.tag)
-
-    def test_deepcopy_classictype(self):
-        from _testcapi import make_copyable
-        x = make_copyable([23])
-        y = copy.deepcopy(x)
-        self.assertEqual(x, y)
-        self.assertEqual(x.tag, y.tag)
-        self.assert_(x is not y)
-        self.assert_(x.tag is not y.tag)
-
-    # regression tests for class-vs-instance and metaclass-confusion
-    def test_copy_classoverinstance(self):
-        class C(object):
-            def __init__(self, v):
-                self.v = v
-            def __cmp__(self, other):
-                return -cmp(other, self.v)
-            def __copy__(self):
-                return self.__class__(self.v)
-        x = C(23)
-        self.assertEqual(copy.copy(x), x)
-        x.__copy__ = lambda: 42
-        self.assertEqual(copy.copy(x), x)
-
-    def test_deepcopy_classoverinstance(self):
-        class C(object):
-            def __init__(self, v):
-                self.v = v
-            def __cmp__(self, other):
-                return -cmp(other, self.v)
-            def __deepcopy__(self, memo):
-                return self.__class__(copy.deepcopy(self.v, memo))
-        x = C(23)
-        self.assertEqual(copy.deepcopy(x), x)
-        x.__deepcopy__ = lambda memo: 42
-        self.assertEqual(copy.deepcopy(x), x)
-
-
-    def test_copy_metaclassconfusion(self):
-        class MyOwnError(copy.Error):
-            pass
-        class Meta(type):
-            def __copy__(cls):
-                raise MyOwnError("can't copy classes w/this metaclass")
-        class C:
-            __metaclass__ = Meta
-            def __init__(self, tag):
-                self.tag = tag
-            def __cmp__(self, other):
-                return -cmp(other, self.tag)
-        # the metaclass can forbid shallow copying of its classes
-        self.assertRaises(MyOwnError, copy.copy, C)
-        # check that there is no interference with instances
-        x = C(23)
-        self.assertEqual(copy.copy(x), x)
-
-    def test_deepcopy_metaclassconfusion(self):
-        class MyOwnError(copy.Error):
-            pass
-        class Meta(type):
-            def __deepcopy__(cls, memo):
-                raise MyOwnError("can't deepcopy classes w/this metaclass")
-        class C:
-            __metaclass__ = Meta
-            def __init__(self, tag):
-                self.tag = tag
-            def __cmp__(self, other):
-                return -cmp(other, self.tag)
-        # types are ALWAYS deepcopied atomically, no matter what
-        self.assertEqual(copy.deepcopy(C), C)
-        # check that there is no interference with instances
-        x = C(23)
-        self.assertEqual(copy.deepcopy(x), x)
-
-    def _nomro(self):
-        class C(type):
-            def __getattribute__(self, attr):
-                if attr == '__mro__':
-                    raise AttributeError, "What, *me*, a __mro__? Nevah!"
-                return super(C, self).__getattribute__(attr)
-        class D(object):
-            __metaclass__ = C
-        return D()
-
-    def test_copy_mro(self):
-        x = self._nomro()
-        y = copy.copy(x)
-
-    def test_deepcopy_mro(self):
-        x = self._nomro()
-        y = copy.deepcopy(x)
-
     # The deepcopy() method
 
     def test_deepcopy_basic(self):
@@ -669,6 +568,22 @@ class TestCopy(unittest.TestCase):
                 raise ValueError, "ain't got no stickin' state"
         self.assertRaises(ValueError, copy.copy, EvilState())
 
+    def test_copy_function(self):
+        self.assertEqual(copy.copy(global_foo), global_foo)
+        def foo(x, y): return x+y
+        self.assertEqual(copy.copy(foo), foo)
+        bar = lambda: None
+        self.assertEqual(copy.copy(bar), bar)
+
+    def test_deepcopy_function(self):
+        self.assertEqual(copy.deepcopy(global_foo), global_foo)
+        def foo(x, y): return x+y
+        self.assertEqual(copy.deepcopy(foo), foo)
+        bar = lambda: None
+        self.assertEqual(copy.deepcopy(bar), bar)
+
+def global_foo(x, y): return x+y
+
 def test_main():
     test_support.run_unittest(TestCopy)
 
