@@ -5,21 +5,22 @@
 
 import dl
 from test.test_support import verbose,TestSkipped
-
 import dircache
 
+libcNames = []
 libcName = ''
 for file in dircache.listdir('/usr/lib/'):
-        if 'libc.so' in file:
-                libcName = file
-                break
-
+        if '/libc.so.' in file:
+                libcNames.append(file)
+# Pick the most recent (highest number) libc
+if len(libcNames) > 0:
+	libcName = sorted(libcNames)[-1]
 if not libcName:
 	raise TestSkipped
 
 sharedlibs = [
     (libcName, 'getpid'),
-    ]
+]
 
 for s, func in sharedlibs:
     try:
