@@ -3,84 +3,57 @@
 import warnings
 warnings.filterwarnings('ignore', r".*posixfile module",
                         DeprecationWarning, 'posixfile$')
-warnings.filterwarnings('ignore', r".*statcache module",
-                        DeprecationWarning, 'statcache$')
+
+warnings.filterwarnings("ignore",
+                        "the gopherlib module is deprecated",
+                        DeprecationWarning,
+                        ".*test_sundry")
 
 from test.test_support import verbose
 
 import BaseHTTPServer
+import DocXMLRPCServer
 import CGIHTTPServer
-import Queue
 import SimpleHTTPServer
-import SocketServer
+import SimpleXMLRPCServer
 import aifc
-import anydbm
 import audiodev
 import bdb
+import cgitb
 import cmd
 import code
-import codeop
-import colorsys
-import commands
 import compileall
-try:
-    import curses   # not available on Windows
-except ImportError:
-    if verbose:
-        print "skipping curses"
-import dircache
-import dis
-import distutils
-import doctest
-import dumbdbm
 import encodings
-import fnmatch
 import formatter
-import fpformat
 import ftplib
 import getpass
-import glob
 import gopherlib
 import htmlentitydefs
-import htmllib
-import httplib
-import imaplib
+import ihooks
 import imghdr
 import imputil
 import keyword
-import macpath
+import linecache
 import macurl2path
 import mailcap
-import mhlib
-import mimetypes
 import mimify
-import multifile
 import mutex
 import nntplib
 import nturl2path
+import opcode
+import os2emxpath
 import pdb
 import pipes
 #import poplib
 import posixfile
-import profile
 import pstats
 import py_compile
-#import reconvert
-import repr
-try:
-    import rlcompleter   # not available on Windows
-except ImportError:
-    if verbose:
-        print "skipping rlcompleter"
-import robotparser
+import pydoc
+import rexec
+import rlcompleter
 import sched
-import sgmllib
-import shelve
-import shlex
-import shutil
 import smtplib
 import sndhdr
-import statcache
 import statvfs
 import stringold
 import sunau
@@ -88,14 +61,17 @@ import sunaudio
 import symbol
 import tabnanny
 import telnetlib
-import test
+import timeit
 import toaiff
-#import tzparse
-import urllib2
+import token
+try:
+    import tty     # not available on Windows
+except ImportError:
+    if verbose:
+        print "skipping tty"
+
 # Can't test the "user" module -- if the user has a ~/.pythonrc.py, it
 # can screw up all sorts of things (esp. if it prints!).
 #import user
 import webbrowser
-import whichdb
-import xdrlib
 import xml
